################################################################
:mod:`.axes <highcharts_core.options.axes>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  accessibility
  breaks
  color_axis
  crosshair
  data_classes
  generic
  labels
  markers
  numeric
  parallel_axes
  plot_bands
  title
  x_axis
  y_axis
  z_axis

--------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.axes <highcharts_core.options.axes>`
    -
  * - :mod:`.options.axes.accessibility <highcharts_core.options.axes.accessibility>`
    - :class:`AxisAccessibility <highcharts_core.options.axes.accessibility.AxisAccessibility>`
  * - :mod:`.options.axes.breaks <highcharts_core.options.axes.breaks>`
    - :class:`AxisBreak <highcharts_core.options.axes.breaks.AxisBreak>`
  * - :mod:`.options.axes.color_axis <highcharts_core.options.axes.color_axis>`
    - :class:`ColorAxis <highcharts_core.options.axes.color_axis.ColorAxis>`
  * - :mod:`.options.axes.crosshair <highcharts_core.options.axes.crosshair>`
    - :class:`CrosshairOptions <highcharts_core.options.axes.crosshair.CrosshairOptions>`
  * - :mod:`.options.axes.data_classes <highcharts_core.options.axes.data_classes>`
    - :class:`DataClass <highcharts_core.options.axes.data_classes.DataClass>`
  * - :mod:`.options.axes.generic <highcharts_core.options.axes.generic>`
    - :class:`GenericAxis <highcharts_core.options.axes.generic.GenericAxis>`
  * - :mod:`.options.axes.labels <highcharts_core.options.axes.labels>`
    - :class:`AxisLabelOptions <highcharts_core.options.axes.labels.AxisLabelOptions>`
      :class:`PlotBandLabel <highcharts_core.options.axes.labels.PlotBandLabel>`
      :class:`PlotLineLabel <highcharts_core.options.axes.labels.PlotLineLabel>`
  * - :mod:`.options.axes.markers <highcharts_core.options.axes.markers>`
    - :class:`AxisMarker <highcharts_core.options.axes.markers.AxisMarker>`
  * - :mod:`.options.axes.numeric <highcharts_core.options.axes.numeric>`
    - :class:`NumericAxis <highcharts_core.options.axes.numeric.NumericAxis>`
  * - :mod:`.options.axes.parallel_axes <highcharts_core.options.axes.parallel_axes>`
    - :class:`ParallelAxesOptions <highcharts_core.options.axes.parallel_axes.ParallelAxesOptions>`
  * - :mod:`.options.axes.plot_bands <highcharts_core.options.axes.plot_bands>`
    - :class:`PlotBand <highcharts_core.options.axes.plot_bands.PlotBand>`
      :class:`PlotLine <highcharts_core.options.axes.plot_bands.PlotLine>`
  * - :mod:`.options.axes.title <highcharts_core.options.axes.title>`
    - :class:`AxisTitle <highcharts_core.options.axes.title.AxisTitle>`
  * - :mod:`.options.axes.x_axis <highcharts_core.options.axes.x_axis>`
    - :class:`XAxis <highcharts_core.options.axes.x_axis.XAxis>`
  * - :mod:`.options.axes.y_axis <highcharts_core.options.axes.y_axis>`
    - :class:`YAxis <highcharts_core.options.axes.y_axis.YAxis>`
      :class:`StackShadow <highcharts_core.options.axes.y_axis.StackShadow>`
  * - :mod:`.options.axes.z_axis <highcharts_core.options.axes.z_axis>`
    - :class:`ZAxis <highcharts_core.options.axes.z_axis.ZAxis>`
